@@ -17,7 +17,6 @@
 #' Used only if internal = FALSE (default = tempdir())
 #' @return aggregated daily Daymet data as a tiff file written
 #' to disk or a raster stack when data is returned to the workspace.
-#' @keywords daymet, climate data
 #' @export
 #' @examples
 #' 
@@ -146,9 +145,11 @@ daymet_grid_agg <- function(
                           sprintf('%s_agg_%s_%s%s.tif', param, year, int, fun))
     
     # write raster object to file
-    raster::writeRaster(x = result,
-                        filename = output_file,
-                        overwrite = TRUE)
+    suppressWarnings(
+      raster::writeRaster(x = result,
+                          filename = output_file,
+                          overwrite = TRUE)  
+    )
   } else {
     # return to workspace
     return(result)
